from setuptools import setup

setup(name='standards',
      version='0.0.1',
      description='Standards',
      author='Bülent Aldemir',
      author_email='buelent@e-evolution.de',
      license='MIT',
      packages=['standards'],
      zip_safe=False)